@@ -10,7 +10,8 @@ logger.setLevel(os.getenv("LOG_LEVEL", "INFO"))
 
 def getLogger(name, toFile=False):
     logger = logging.getLogger(name)
-    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s -%(message)s')
+    feedLogger = logging.getLogger('feed')
+    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s -%(message)s |%(filename)s:%(lineno)d')
     ch.setLevel(os.getenv("LOG_LEVEL", "DEBUG"))
     ch.setFormatter(formatter)
     logger.setLevel(os.getenv("LOG_LEVEL", "INFO"))
@@ -23,6 +24,15 @@ def getLogger(name, toFile=False):
         fileHandler.setFormatter(formatter)
         fileHandler.setLevel(os.getenv('FILE_LOGLEVEL', 'INFO'))
         logger.addHandler(fileHandler)
+    feedLogger.addHandler(ch)
     return logger
 
+def initialiseSrcLogger():
+    handler = logging.StreamHandler(stream=sys.stderr)
+    handler.setLevel(os.getenv("LOG_LEVEL", "DEBUG"))
+    formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s -%(message)s |%(filename)s:%(lineno)d')
+    handler.setFormatter(formatter)
+    srcLogger = logging.getLogger('src.main')
+    srcLogger.addHandler(handler)
+
 
