@@ -8,16 +8,13 @@ kafka_params = {
 
 browser_params = {
     "internal_port":  4444,
-    "host": os.getenv("BROWSER_CONTAINER_HOST", None),
+    "host": os.getenv("BROWSER_CONTAINER_HOST", 'localhost'),
     "image": os.getenv('BROWSER_IMAGE', 'selenium/standalone-chrome:3.141.59'),
-    "base": os.getenv('BROWSER_BASE_PORT', 4444),
+    "port": os.getenv('BROWSER_PORT', 4444),
     "max": os.getenv("MAX_FEEDS", 10),
     "base_port": os.getenv("BROWSER_BASE_PORT", 4444)
 }
 
-hazelcast_params = {
-    "host": os.getenv("HAZELCAST_HOST", "localhost"), "port": os.getenv("HAZELCAST_PORT", 5701)
-}
 
 mongo_params = {
     "host": os.getenv("MONGO_HOST", "localhost:27017"),
@@ -42,7 +39,7 @@ database_parameters = {
 
 ui_server_params = {
     "host": os.getenv('UISERVER_HOST', 'localhost'),
-    "port": os.getenv('UISERVER_PORT', 5004) # ui-server
+    "port": os.getenv('FLASK_PORT', 5004) # ui-server
     }
 nanny_params = {
     "host": os.getenv("NANNY_HOST", "localhost"),
